@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import *
+from django.conf.urls import *
 
 urlpatterns = patterns('nano.activation.views',
     url(r'^activate$',         'activate_key', name='nano-activate-key'),
